ComplexMCA
==========

.. currentmodule:: xeofs.cross

.. autoclass:: ComplexMCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ComplexMCA.__init__
      ~ComplexMCA.components
      ~ComplexMCA.components_amplitude
      ~ComplexMCA.components_phase
      ~ComplexMCA.compute
      ~ComplexMCA.correlation_coefficients_X
      ~ComplexMCA.correlation_coefficients_Y
      ~ComplexMCA.covariance_fraction_CD95
      ~ComplexMCA.cross_correlation_coefficients
      ~ComplexMCA.deserialize
      ~ComplexMCA.fit
      ~ComplexMCA.fraction_variance_X_explained_by_X
      ~ComplexMCA.fraction_variance_Y_explained_by_X
      ~ComplexMCA.fraction_variance_Y_explained_by_Y
      ~ComplexMCA.get_params
      ~ComplexMCA.get_serialization_attrs
      ~ComplexMCA.heterogeneous_patterns
      ~ComplexMCA.homogeneous_patterns
      ~ComplexMCA.inverse_transform
      ~ComplexMCA.load
      ~ComplexMCA.predict
      ~ComplexMCA.save
      ~ComplexMCA.scores
      ~ComplexMCA.scores_amplitude
      ~ComplexMCA.scores_phase
      ~ComplexMCA.serialize
      ~ComplexMCA.squared_covariance_fraction
      ~ComplexMCA.transform
   
   

   
   
   